==> kubernetes-model-1.0.52-sources.jar: io/fabric8/openshift/api/model/TemplateListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.List;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Object;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;

public interface TemplateListFluent<A extends TemplateListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public A addToItems(Template... items);
    public A removeFromItems(Template... items);
    public List<Template> getItems();
    public A withItems(List<Template> items);
    public A withItems(Template... items);
    public TemplateListFluent.ItemsNested<A> addNewItem();
    public TemplateListFluent.ItemsNested<A> addNewItemLike(Template item);
    public String getKind();
    public A withKind(String kind);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public TemplateListFluent.MetadataNested<A> withNewMetadata();
    public TemplateListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public TemplateListFluent.MetadataNested<A> editMetadata();
    public A withNewMetadata(String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,TemplateFluent<TemplateListFluent.ItemsNested<N>>{

        
    public N endItem();    public N and();
}
    public interface MetadataNested<N> extends Nested<N>,ListMetaFluent<TemplateListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/openshift/api/model/TemplateListFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.ListMeta;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface TemplateListFluent<A extends TemplateListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public A addToItems(Template... items);
    public A removeFromItems(Template... items);
    public List<Template> getItems();
    public A withItems(List<Template> items);
    public A withItems(Template... items);
    public TemplateListFluent.ItemsNested<A> addNewItem();
    public TemplateListFluent.ItemsNested<A> addNewItemLike(Template item);
    public String getKind();
    public A withKind(String kind);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public TemplateListFluent.MetadataNested<A> withNewMetadata();
    public TemplateListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public TemplateListFluent.MetadataNested<A> editMetadata();
    public TemplateListFluent.MetadataNested<A> editOrNewMetadata();
    public TemplateListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public A withNewMetadata(String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TemplateFluent<TemplateListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<TemplateListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
